ComConfig class

Constructors

ComConfig({required Widget loadingWidget, required Widget emptyWidget, required Widget errorWidget, required Widget noNetworkWidget(VoidCallback? onReconnect)})
const
ComConfig.defaults()
factory

Properties

emptyWidget → Widget
final
errorWidget → Widget
final
hashCode → int
The hash code for this object.
no setterinherited
loadingWidget → Widget
final
noNetworkWidget → Widget Function(VoidCallback? onReconnect)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Widget? loadingWidget, Widget? emptyWidget, Widget? errorWidget, Widget noNetworkWidget(VoidCallback? onReconnect)?}) → ComConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultsConfig → const ComConfig