Log class

Constructors

Log()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

clearLogDirectoryLogs() → Future<bool>
console(String message, {DateTime? time, int level = 500, String name = '', Object? error, StackTrace? stackTrace}) → void
d(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
dispose() → Future<void>
e(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
getLogDir() → Future<Directory>
getLogDirectorySize() → Future<int>
i(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void
init(LogConfig config) → Future<void>
readLatestLogs() → Future<List<String>>
w(dynamic message, {DateTime? time, Object? error, StackTrace? stackTrace}) → void