DeveloperOutput class

Constructors

DeveloperOutput({String name = 'LOG', bool forwardMetadata = true})

Properties

forwardMetadata → bool
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → Future<void>
inherited
init() → Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output(OutputEvent event) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

sanitize(String text) → String