IsolateFileOutput class

Constructors

IsolateFileOutput(LogConfig config)

Properties

config → LogConfig
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → Future<void>
init() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output(OutputEvent event) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

rootIsolateTokenProvider ↔ RootIsolateToken? Function()
getter/setter pair