HttpResponse<T> class

Constructors

HttpResponse({required int code, String? message, T? data})
HttpResponse.fromJson(Map<String, dynamic> json, {T fromJsonT(dynamic json)?})
factory

Properties

code → int
final
data → T?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

mapData<R>(R mapper(T? data)) → HttpResponse<R>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited