RetryInterceptor class

Constructors

RetryInterceptor({required Dio dio, int maxRetries = 3, Duration initialDelay = const Duration(seconds: 1), Duration maxDelay = const Duration(seconds: 30), double jitterFactor = 0.2, Set<String> retryableMethods = defaultRetryableMethods})
factory

Properties

dio → Dio
final
hashCode → int
The hash code for this object.
no setterinherited
initialDelay → Duration
final
jitterFactor → double
final
maxDelay → Duration
final
maxRetries → int
final
retryableMethods → Set<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → Future<void>
Called when an exception was occurred during the request.
onRequest(RequestOptions options, RequestInterceptorHandler handler) → void
Called when the request is about to be sent.
inherited
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultRetryableMethods → const Set<String>