network/network library
Classes
- ComAppLog
- ComAppLogDetailPage
- ComDebugConfig
- ComDebugLogger
- Generic entry point for the unified debug panel.
- ComDebugManager
- ComErrorDetails
- ComNetworkDebug
- ComNetworkDebugInterceptor
- ComNetworkLogDetailPage
- ComNetworkLogger
- ComNetworkLogListPage
- ComPushDebug
- ComPushLogDetailPage
- ComRequestDetails
- ComResponseDetails
- ComSlowLogsExport
- ComStorageDebug
- ComStorageEntry
- A real storage entry supplied by the host application's storage adapter.
- ComStorageLogDetailPage
- ComWebSocketDebug
- ComWebSocketLogDetailPage
- ComWebSocketMessage
- ComWebSocketMessageDetailPage
- HttpClient
- HttpConfig
-
HttpResponse<
T> - NetworkRequestExtras
- RetryInterceptor
Enums
- ComDebugExportType
- ComDebugLogLevel
- ComPushEventType
- Provider-agnostic push lifecycle events reported by the host application.
- ComStorageOperation
- Provider-agnostic storage operations reported by the host application.
- ComWebSocketMessageDirection
- ComWebSocketStatus
- HttpLogField
- HttpMethod
Functions
-
defaultComBusinessCodeSuccess(
int code) → bool
Typedefs
- ComAppLogSanitizer = ComAppLog Function(ComAppLog)
- ComBusinessCodeSuccessPredicate = bool Function(int code)
- ComLogSanitizer = ComNetworkDebug Function(ComNetworkDebug)
- ComPushLogSanitizer = ComPushDebug Function(ComPushDebug)
-
ComSlowLogsExporter
= FutureOr<
void> Function(ComSlowLogsExport export) -
ComStorageClearHandler
= FutureOr<
bool> Function() -
ComStorageDeleteHandler
= FutureOr<
bool> Function(String storage, String key) -
ComStorageEntriesLoader
= FutureOr<
Iterable< Function()ComStorageEntry> > - ComStorageLogSanitizer = ComStorageDebug Function(ComStorageDebug)
- ComWebSocketLogSanitizer = ComWebSocketDebug Function(ComWebSocketDebug)
- ComWebSocketMessageSanitizer = ComWebSocketMessage Function(ComWebSocketMessage)
- HttpLogEnabledPredicate = bool Function()
- 控制台网络日志动态开关。
- HttpLogSanitizer = dynamic Function(HttpLogField field, dynamic value)
- 控制台网络日志值处理器。未配置时不做任何默认脱敏。