NetworkRequestExtras class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- isTokenRefresh → const String
- retryCount → const String
- skipAuth → const String
- skipRetry → const String
- skipTokenRefresh → const String
- tokenRefreshed → const String