ComSpacing class

Annotations

Constructors

ComSpacing({required double extraSmall, required double small, required double medium, required double large, required double extraLarge, EdgeInsets? cardPadding})
const

Properties

cardPadding → EdgeInsets?
组件间距
final
extraLarge → double
final
extraSmall → double
基础间距体系
final
hashCode → int
The hash code for this object.
no setterinherited
large → double
final
medium → double
final
resolvedCardPadding → EdgeInsets
获取组件最终值(优先使用组件级配置)
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
small → double
final

Methods

copyWith({double? extraSmall, double? small, double? medium, double? large, double? extraLarge, EdgeInsets? cardPadding}) → ComSpacing
拷贝方法
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

lerp(ComSpacing a, ComSpacing b, double t) → ComSpacing
插值计算

Constants

compact → const ComSpacing
紧凑配置
relaxed → const ComSpacing
宽松配置
standard → const ComSpacing
默认配置