ComTheme class

Inheritance
Annotations

Constructors

ComTheme({required ComShapes shapes, required ComSpacing spacing, required Color? success, required Color? error, required Color? warning, required Color? info, required Color? link})
const
ComTheme.dark()
factory
ComTheme.light()
factory

Properties

error → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
info → Color?
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapes → ComShapes
final
spacing → ComSpacing
final
success → Color?
final
type → Object
The extension's type.
no setterinherited
warning → Color?
final

Methods

copyWith({ComShapes? shapes, ComSpacing? spacing, Color? success, Color? error, Color? warning, Color? info, Color? link}) → ComTheme
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<ComTheme>? other, double t) → ComTheme
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited