ComBannerManager class
Methods
-
clearAll()
→ void
-
-
clearMessageFilter()
→ void
-
-
clearQueue()
→ void
-
-
close(int id, ComBannerClosedReason reason)
→ Future<void>
-
-
didChangeAccessibilityFeatures()
→ void
-
Called when the system changes the set of currently active accessibility
features.
inherited
-
didChangeAppLifecycleState(AppLifecycleState state)
→ void
-
Called when the system puts the app in the background or returns
the app to the foreground.
override
-
didChangeLocales(List<Locale>? locales)
→ void
-
Called when the system tells the app that the user's locale has
changed. For example, if the user changes the system language
settings.
inherited
-
didChangeMetrics()
→ void
-
Called when the application's dimensions change. For example,
when a phone is rotated.
inherited
-
didChangePlatformBrightness()
→ void
-
Called when the platform brightness changes.
inherited
-
didChangeTextScaleFactor()
→ void
-
Called when the platform's text scale factor changes.
inherited
-
didChangeViewFocus(ViewFocusEvent event)
→ void
-
Called whenever the PlatformDispatcher receives a notification that the
focus state on a view has changed.
inherited
-
didHaveMemoryPressure()
→ void
-
Called when the system is running low on memory.
inherited
-
didPopRoute()
→ Future<bool>
-
Called when the system tells the app to pop the current route, such as
after a system back button press or back gesture.
inherited
-
didPushRoute(String route)
→ Future<bool>
-
Called when the host tells the application to push a new route onto the
navigator.
inherited
-
didPushRouteInformation(RouteInformation routeInformation)
→ Future<bool>
-
Called when the host tells the application to push a new
RouteInformation and a restoration state onto the router.
inherited
-
didRequestAppExit()
→ Future<AppExitResponse>
-
Called when a request is received from the system to exit the application.
inherited
-
dismissCurrent([ComBannerClosedReason reason = ComBannerClosedReason.programmatic])
→ Future<void>
-
-
getConfigForType(ComToastType type)
→ ComToastConfig
-
-
handleCancelBackGesture()
→ void
-
Called when a predictive back gesture is canceled, indicating that no
navigation should occur.
inherited
-
handleCommitBackGesture()
→ void
-
Called when a predictive back gesture is finished successfully, indicating
that the current route should be popped.
inherited
-
handleStartBackGesture(PredictiveBackEvent backEvent)
→ bool
-
Called at the start of a predictive back gesture.
inherited
-
handleStatusBarTap()
→ void
-
Called when the user taps the status bar on iOS, to scroll a scroll
view to the top.
inherited
-
handleUpdateBackGestureProgress(PredictiveBackEvent backEvent)
→ void
-
Called when a predictive back gesture moves.
inherited
-
init({ComToastStateTheme? theme})
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setDuplicateFilterDuration(int milliseconds)
→ void
-
-
setQueueLimit(int maxPendingBanners)
→ void
-
-
show({required String message, required ComToastConfig config, required ComToastBannerContent? content, required ComBannerBuilder? builder, required ComBannerOptions options, required Object duplicateKey, bool skipDuplicateFilter = false})
→ ComBannerController
-
-
toString()
→ String
-
A string representation of this object.
inherited