ComBannerClosedReason enum

Inheritance
Available extensions

Values

timeout → const ComBannerClosedReason
swipe → const ComBannerClosedReason
tap → const ComBannerClosedReason
closeButton → const ComBannerClosedReason
programmatic → const ComBannerClosedReason
replaced → const ComBannerClosedReason
dropped → const ComBannerClosedReason
queueOverflow → const ComBannerClosedReason
duplicate → const ComBannerClosedReason
cleared → const ComBannerClosedReason
failedToShow → const ComBannerClosedReason

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ComBannerClosedReason>
A constant List of the values in this enum, in order of their declaration.