ComBannerOptions class

Constructors

ComBannerOptions({Object? queueKey, ComBannerQueuePolicy queuePolicy = ComBannerQueuePolicy.enqueue, bool dismissOnTap = true, bool swipeDismissible = true, bool pauseOnInteraction = true, Duration exitDuration = const Duration(milliseconds: 220), Duration reboundDuration = const Duration(milliseconds: 180), double swipeThreshold = 0.25, double swipeVelocity = 700})
const

Properties

dismissOnTap → bool
final
exitDuration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
pauseOnInteraction → bool
final
queueKey → Object?
final
queuePolicy → ComBannerQueuePolicy
final
reboundDuration → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
swipeDismissible → bool
final
swipeThreshold → double
final
swipeVelocity → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited