ComOverlayManager class

Overlay管理器基类 提供Toast和Loading的共用Overlay管理功能

Constructors

ComOverlayManager()
factory

Properties

hasBannerEntries → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
isLoadingShowing → bool
获取Loading状态
no setter
isToastShowing → bool
获取Toast状态
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAll() → void
清理所有Overlay
hideBannerEntry() → void
hideLoadingEntry() → void
隐藏Loading Entry
hideToastEntry() → void
隐藏Toast Entry
markBannerEntryNeedsBuild() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showBannerEntry(OverlayEntry entry) → bool
showLoadingEntry(OverlayEntry entry) → bool
显示Loading Entry
showToastEntry(OverlayEntry entry) → bool
显示Toast Entry
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited