ComToastTheme class

Constructors

ComToastTheme({ComToastStateTheme toast = const ComToastStateTheme(), ComToastStateTheme banner = const ComToastStateTheme(), ComToastConfig? loading})
const

Properties

final
hashCode int
The hash code for this object.
no setterinherited
loading ComToastConfig?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toast ComToastStateTheme
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited