ComToastManager class

Constructors

ComToastManager()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isShowing → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearMessageFilter() → void
dismiss() → void
getLoadingConfig() → ComToastConfig
getToastConfigForType(ComToastType type) → ComToastConfig
init({ComToastTheme? theme}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDuplicateFilterDuration(int milliseconds) → void
show(String message, {ComToastConfig? config, bool skipDuplicateFilter = false}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited