dismissWithAnimation method
Implementation
Future<void> dismissWithAnimation() async {
try {
await _controller.reverse();
} catch (_) {
// The manager still removes the overlay if animation is interrupted.
}
}
Future<void> dismissWithAnimation() async {
try {
await _controller.reverse();
} catch (_) {
// The manager still removes the overlay if animation is interrupted.
}
}