FunctionValueProxy<T> class

Constructors

FunctionValueProxy(ValueChanged<T>? target, {int? timeout, bool trailing = false, bool immediate = false, String? id})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
immediate → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → ValueChanged<T>?
final
timeout → int
final
trailing → bool
final

Methods

debounce(T value) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
throttle(T value) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

cancelDebounce(String id) → void
cancelThrottle(String id) → void