PlatformUtil class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isAndroid bool
no setter
isApple bool
no setter
isDesktop bool
no setter
isFuchsia bool
no setter
isIOS bool
no setter
isLinux bool
no setter
isMacOS bool
no setter
isMobile bool
no setter
isOhos bool
no setter
isWeb bool
no setter
isWindows bool
no setter
localHostname String
no setter
numberOfProcessors int
no setter
osVersion String
no setter
platformName String
no setter
platformType PlatformType
no setter
script String
no setter