ComDraggable class

Inheritance

Constructors

ComDraggable({Key? key, required Widget child, required Size childSize, double initialRight = 0, double initialBottom = 0, bool draggable = true, bool snapToEdge = true, bool useSafeArea = true, EdgeInsets boundaryMargin = EdgeInsets.zero, Clip clipBehavior = Clip.none, Duration snapAnimationDuration = const Duration(milliseconds: 300), Curve snapAnimationCurve = Curves.easeOutCubic, ValueChanged<Offset>? onPositionChanged, Widget builder(BuildContext context, Widget child, bool isDragging)?})
const

Properties

boundaryMargin → EdgeInsets
final
builder → Widget Function(BuildContext context, Widget child, bool isDragging)?
final
child → Widget
final
childSize → Size
final
clipBehavior → Clip
final
draggable → bool
final
hashCode → int
The hash code for this object.
no setterinherited
initialBottom → double
final
initialRight → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPositionChanged → ValueChanged<Offset>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapAnimationCurve → Curve
final
snapAnimationDuration → Duration
final
snapToEdge → bool
final
useSafeArea → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ComDraggable>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited