IRefreshState<T> class abstract

刷新状态接口

Implementers

Constructors

IRefreshState()

Properties

dataList → List<T>
no setter
error → String?
no setter
hasError → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasMore → bool
no setter
initialRefresh → bool
no setter
isLoadingMore → bool
no setter
isRefreshing → bool
no setter
pageNum → int
no setter
pageSize → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited