RefreshState<T> class

Implemented types

Constructors

RefreshState()

Properties

dataList → List<T>
no setteroverride
error → String?
no setteroverride
hasError → bool
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
hasMore → bool
no setteroverride
initialRefresh → bool
no setteroverride
isLoadingMore → bool
no setteroverride
isRefreshing → bool
no setteroverride
pageNum → int
no setteroverride
pageSize → int
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addData(List<T> newData) → void
clear() → void
clearError() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateState({int? pageNum, int? pageSize, bool? hasMore, List<T>? dataList, bool? initialRefresh, bool? isRefreshing, bool? isLoadingMore, String? error}) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited