GridRefreshStrategy<T> class

网格布局策略

Implemented types

Constructors

GridRefreshStrategy({int crossAxisCount = 2, double mainAxisSpacing = 12, double crossAxisSpacing = 12, Widget loadingBuilder(BuildContext)?, Widget errorBuilder(BuildContext)?, Widget emptyBuilder(BuildContext)?})
const

Properties

crossAxisCount → int
final
crossAxisSpacing → double
final
emptyBuilder → Widget Function(BuildContext)?
final
errorBuilder → Widget Function(BuildContext)?
final
hashCode → int
The hash code for this object.
no setterinherited
loadingBuilder → Widget Function(BuildContext)?
final
mainAxisSpacing → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildLayout({required BuildContext context, required IRefreshState<T> state, required Widget itemBuilder(BuildContext, T, int)}) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited