ListRefreshStrategy<T> class

列表布局策略

Implemented types

Constructors

ListRefreshStrategy({ScrollController? scrollController, bool? primary, ScrollPhysics? physics, bool shrinkWrap = false, EdgeInsetsGeometry? padding, double? itemExtent, Widget? prototypeItem, double? scrollCacheExtent, @Deprecated('Use scrollCacheExtent instead.') double? cacheExtent, int? semanticChildCount, String? restorationId, Clip clipBehavior = Clip.hardEdge, Widget loadingBuilder(BuildContext)?, Widget errorBuilder(BuildContext)?, Widget emptyBuilder(BuildContext)?})

Properties

cacheExtent → double?
no setter
clipBehavior → Clip
final
emptyBuilder → Widget Function(BuildContext)?
final
errorBuilder → Widget Function(BuildContext)?
final
hashCode → int
The hash code for this object.
no setterinherited
itemExtent → double?
final
loadingBuilder → Widget Function(BuildContext)?
final
padding → EdgeInsetsGeometry?
final
physics → ScrollPhysics?
final
primary → bool?
final
prototypeItem → Widget?
final
restorationId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollCacheExtent → double?
final
scrollController → ScrollController?
final
semanticChildCount → int?
final
shrinkWrap → bool
final

Methods

buildLayout({required BuildContext context, required IRefreshState<T> state, required Widget itemBuilder(BuildContext, T, int)}) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited