ComToastStateTheme class

Constructors

ComToastStateTheme({ComToastConfig? base, ComToastConfig? normal, ComToastConfig? success, ComToastConfig? error, ComToastConfig? warning, ComToastConfig? info})
const

Properties

base ComToastConfig?
final
error ComToastConfig?
final
hashCode int
The hash code for this object.
no setterinherited
info ComToastConfig?
final
normal ComToastConfig?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success ComToastConfig?
final
warning ComToastConfig?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(ComToastType type, ComToastConfig defaultConfig) ComToastConfig
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited